@@ -1,10 +1,12 @@
+#! perl
+
 # Postgres.pm -- EekBoek driver for PostgreSQL dsatabase
-# RCS Info        : $Id$
+# RCS Info        : $Id: Postgres.pm,v 1.25 2008/02/17 16:47:49 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Tue Jan 24 10:43:00 2006
 # Last Modified By: Johan Vromans
-# Last Modified On: Tue Oct 24 15:41:19 2006
-# Update Count    : 164
+# Last Modified On: Sun Feb 17 17:37:54 2008
+# Update Count    : 171
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -15,6 +17,9 @@ package EB::DB::Postgres;
 
 use strict;
 use warnings;
+
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.25 $ =~ /(\d+)/g;
+
 use EB;
 use DBI;
 use DBD::Pg;
@@ -71,7 +76,9 @@ sub create {
 
     $dbname =~ s/^(?!=eekboek_)/eekboek_/;
 
-    my $sql = "CREATE DATABASE $dbname";
+    # Normally, sql treats names as lowcased. By using " " we can
+    # maintain the case of the database name.
+    my $sql = "CREATE DATABASE \"$dbname\"";
     $sql .= " ENCODING 'UNICODE'";
     for ( $cfg->val("database", "user", undef) ) {
 	next unless $_;
@@ -261,14 +268,16 @@ sub feature {
     # Unknown/unsupported features may be ignored.
 
     if ( $feat eq "pgcopy" ) {
-	return 1 if ($DBD::Pg::VERSION||0) >= 1.41;
+	return 1 if ($DBD::Pg::VERSION||"0") ge "1.41";
 	warn("%"."Not using PostgreSQL fast load. DBD::Pg::VERSION = ",
-	     ($DBD::Pg::VERSION||0), ", needs 1.41 or later\n");
+	     ($DBD::Pg::VERSION||"0"), ", needs 1.41 or later\n");
 	return;
     }
 
     return 1 if $feat eq "prepcache";
 
+    return 1 if $feat eq "import";
+
     # Return false for all others.
     return;
 }
