@@ -1,10 +1,12 @@
+#! perl
+
 # Sqlite.pm -- EekBoek driver for SQLite database
-# RCS Info        : $Id$
+# RCS Info        : $Id: Sqlite.pm,v 1.8.4.1 2010/01/06 10:50:30 jv Exp $
 # Author          : Johan Vromans
 # Created On      : Sat Oct  7 10:10:36 2006
 # Last Modified By: Johan Vromans
-# Last Modified On: Wed Dec 27 15:13:08 2006
-# Update Count    : 139
+# Last Modified On: Mon Dec 28 21:09:09 2009
+# Update Count    : 150
 # Status          : Unknown, Use with caution!
 
 package main;
@@ -15,6 +17,9 @@ package EB::DB::Sqlite;
 
 use strict;
 use warnings;
+
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.8.4.1 $ =~ /(\d+)/g;
+
 use EB;
 use DBI;
 
@@ -96,6 +101,9 @@ sub connect {
 	$sdb = $dbh;
     }
 
+    # ???
+    $dbh->{unicode} = 1 if $cfg->val(qw(locale unicode));
+
     # Create some missing functions.
     register_functions();
 
@@ -113,6 +121,17 @@ sub disconnect {
     undef $dataset;
 }
 
+# API: Clear database contents, including tables and such.
+sub clear {
+    my ($self) = @_;
+    croak("?INTERNAL ERROR: clear db while not connected") unless $dbh;
+    croak("?INTERNAL ERROR: clear db not supperted by this driver");
+    my $ds = $dataset;
+    $self->disconnect;
+    $self->create($ds);
+    $self->connect($ds);
+}
+
 # API: Setup whatever is needed.
 sub setup {
     # setup will be called after the connection to the database has
@@ -152,7 +171,7 @@ sub get_tables {
     foreach ( $dbh->tables ) {
 	# SQLite returns table names with quotes.
 	# Our tables all start with an uppercase letter.
-	next unless /^"([[:upper:]].+)"$/i;
+	next unless /^"(?:main"\.")?([[:upper:]].+)"$/i;
 	push(@t, lc($1));
     }
     \@t;
@@ -258,6 +277,8 @@ sub feature {
 
     return 1 if $feat eq "prepcache";
 
+    return 0 if $feat eq "import";
+
     # Return false for all others.
     return;
 }
