@@ -1,10 +1,8 @@
-#!/usr/bin/perl -w
-my $RCS_Id = '$Id$ ';
+#! perl
 
 package main;
 
 our $config;
-our $app;
 our $dbh;
 
 package EB::Report::Open;
@@ -12,8 +10,8 @@ package EB::Report::Open;
 # Author          : Johan Vromans
 # Created On      : Fri Sep 30 17:48:16 2005
 # Last Modified By: Johan Vromans
-# Last Modified On: Sat Apr 15 10:48:01 2006
-# Update Count    : 192
+# Last Modified On: Wed Mar 12 16:11:36 2008
+# Update Count    : 204
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -21,10 +19,13 @@ package EB::Report::Open;
 use strict;
 use warnings;
 
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.21 $ =~ /(\d+)/g;
+
 ################ The Process ################
 
 use EB;
 use EB::Format;
+use EB::Report::GenBase;
 
 ################ Subroutines ################
 
@@ -33,7 +34,7 @@ sub new {
 }
 
 sub perform {
-    my ($self, $opts) = @_;
+    my ($self, $opts, $args) = @_;
 
     $opts->{STYLE} = "openstaand";
     $opts->{LAYOUT} =
@@ -49,6 +50,20 @@ sub perform {
 
     my $per = $rep->{per} = $rep->{periode}->[1];
     $rep->{periodex} = 1;	# force 'per'.
+    my $sel;
+    if ( $opts->{deb} && !$opts->{crd} ) {
+	$sel = " AND dbk_type = @{[DBKTYPE_VERKOOP]}";
+    }
+    elsif ( !$opts->{deb} && $opts->{crd} ) {
+	$sel = " AND dbk_type = @{[DBKTYPE_INKOOP]}";
+    }
+    else {
+	$sel = " AND dbk_type in (@{[DBKTYPE_INKOOP]},@{[DBKTYPE_VERKOOP]})";
+    }
+
+    if ( $args && @$args == 1 ) {
+	$sel .= " AND bsr_rel_code = ?";
+    }
 
     my $eb = $opts->{eb_handle};
 
@@ -60,10 +75,10 @@ sub perform {
 			     " FROM Boekstukken, Dagboeken, Boekstukregels".
 			     " WHERE bsk_dbk_id = dbk_id".
 			     " AND bsr_bsk_id = bsk_id AND bsr_nr = 1".
-			     " AND dbk_type in (@{[DBKTYPE_INKOOP]},@{[DBKTYPE_VERKOOP]})".
 			     " AND bsk_date <= ?".
+			     $sel.
 			     " ORDER BY dbk_acc_id, bsr_rel_code, bsk_date",
-			     $per);
+			     $per, @$args);
 
     $rep->start(_T("Openstaande posten"));
 
@@ -78,7 +93,7 @@ sub perform {
 	# Correct for future payments.
 	my $rop = $dbh->do("SELECT sum(bsr_amount)".
 			   " FROM Boekstukregels".
-			   " WHERE bsr_type IN (1,2)".
+			   " WHERE bsr_type IN (@{[DBKTYPE_INKOOP]},@{[DBKTYPE_VERKOOP]})".
 			   " AND bsr_date > ?".
 			   " AND bsr_paid = ?",
 			   $per, $bsk_id);
@@ -118,7 +133,8 @@ sub perform {
 	}
 
 	my $bsk;
-	my $style = "data";
+	my $style = $dbk_type == DBKTYPE_INKOOP ? "cdata" :
+	  $dbk_type == DBKTYPE_VERKOOP ? "ddata" : "data";
 	if ( $bsk_date lt $rep->{per_begin} ) {
 	    $bsk = join(":", $dbk_desc, $bsk_bky, $bsk_nr);
 	    $style = "prevdata";
@@ -169,14 +185,9 @@ sub perform {
 
 package EB::Report::Open::Text;
 
-use EB;
-use base qw(EB::Report::Reporter::Text);
 use strict;
-
-sub new {
-    my ($class, $opts) = @_;
-    $class->SUPER::new($opts->{STYLE}, $opts->{LAYOUT});
-}
+use warnings;
+use base qw(EB::Report::Reporter::Text);
 
 # Style mods.
 
@@ -203,24 +214,15 @@ sub style {
 
 package EB::Report::Open::Html;
 
-use EB;
-use base qw(EB::Report::Reporter::Html);
 use strict;
-
-sub new {
-    my ($class, $opts) = @_;
-    $class->SUPER::new($opts->{STYLE}, $opts->{LAYOUT});
-}
+use warnings;
+use base qw(EB::Report::Reporter::Html);
 
 package EB::Report::Open::Csv;
 
-use EB;
+use strict;
+use warnings;
 use base qw(EB::Report::Reporter::Csv);
 
-sub new {
-    my ($class, $opts) = @_;
-    $class->SUPER::new($opts->{STYLE}, $opts->{LAYOUT});
-}
-
 1;
 
