@@ -1,10 +1,13 @@
+#! perl
+
 package EB::Shell::Base;
 
 # Sorry, I had to modify a few things -- jv
 
+# RCS Id          : $Id: Base.pm,v 1.21.4.1 2009/12/28 12:31:47 jv Exp $
+
 # ----------------------------------------------------------------------
 # Shell::Base - A generic class to build line-oriented command interpreters.
-# $Id$
 # ----------------------------------------------------------------------
 # Copyright (C) 2003 darren chamberlain <darren@cpan.org>
 #
@@ -13,6 +16,9 @@ package EB::Shell::Base;
 # ----------------------------------------------------------------------
 
 use strict;
+
+our $VERSION = sprintf "%d.%03d", q$Revision: 1.21.4.1 $ =~ /(\d+)/g;
+
 use EB;
 use vars qw( $XXVERSION $REVISION $PROMPT
              $RE_QUIT $RE_HELP $RE_SHEBANG
@@ -25,8 +31,8 @@ use File::Basename qw(basename);
 #use Term::Size qw(chars);	# not needed - jv
 use Text::ParseWords qw(shellwords);
 
-$XXVERSION    = 0.05;   # $Date$
-$REVISION     = sprintf "%d.%02d", q$Revision$ =~ /(\d+)\.(\d+)/;
+$XXVERSION    = 0.05;   # $Date: 2009/12/28 12:31:47 $
+$REVISION     = sprintf "%d.%02d", q$Revision: 1.21.4.1 $ =~ /(\d+)\.(\d+)/;
 $RE_QUIT      = '(?i)^\s*(exit|quit|logout)' unless defined $RE_QUIT;
 $RE_HELP      = '(?i)^\s*(help|\?)'          unless defined $RE_HELP;
 $RE_SHEBANG   = '^\s*!\s*$'                  unless defined $RE_SHEBANG;
@@ -155,6 +161,10 @@ sub init_rl {
     require Term::ReadLine;
     $self->term($term = Term::ReadLine->new(ref $self));
 
+    if ( -t STDIN && $term->ReadLine ne 'Term::ReadLine::Gnu' ) {
+	warn("%Voor meer gebruiksgemak tijdens het typen kunt u de module Term::ReadLine::Gnu installeren.\n");
+    }
+
     # Setup default tab-completion function.
     $attr = $term->Attribs;
     $attr->{completion_function} = sub { $self->complete(@_) };
@@ -372,6 +382,13 @@ sub run {
         $line = $self->precmd($line);
 
         ($cmd, $env, @args) = $self->parseline($line);
+
+	# If there's a quoting mistake, parseline returns nothing.
+	if ( $line =~ /\S/ && $cmd !~ /\S/ ) {
+	    warn("?Fout in de invoerregel. Controleer de \" en ' tekens.\n");
+	    next;
+	}
+
         local %ENV = (%ENV, %$env);
 
         if (! length($cmd)) {
@@ -399,25 +416,40 @@ sub run {
 		    next;
 		}
 	    }
-	    $meth = "do_$cmd";
+	    $meth = "do_".lc($cmd);
 	    if ( $self->can($meth) ) {
 		eval {
+		    # Check warnings for ? (errors).
+		    my $fail = 0;
+		    local $SIG{__WARN__} = sub {
+			$fail++ if $_[0] =~ /^\?/;
+			warn(@_);
+		    };
 		    $output = $self->$meth(@args);
+		    # Throw error if errors detected.
+		    die(bless {}, 'FatalError') if $fail && $self->{errexit};
 		};
 		if ($@) {
 # jv                $output = sprintf "%s: Bad command or filename", $self->progname;
-		    my $err = $@;
-		    chomp $err;
-# jv                warn "$output ($err)\n";
-		    warn "?$err\n";
+		    unless ( UNIVERSAL::isa($@, 'FatalError') ) {
+			my $err = $@;
+			chomp $err;
+			# jv                warn "$output ($err)\n";
+			warn "?$err\n";
+		    }
 		    eval {
 			$output = $self->default($cmd, @args);
 		    };
+		    if ( $self->{errexit} ) {
+			warn("?"._T(" ****** Afgebroken wegens fouten in de invoer ******")."\n");
+			$self->quit(1);
+		    }
 		}
 	    }
 	    else {
 		warn("?"._T("Onbekende opdracht. \"help\" geeft een lijst van mogelijke opdrachten.")."\n");
 		undef($output);
+		$self->quit(1) if $self->{errexit};
 	    }
         }
 
@@ -436,7 +468,7 @@ sub run {
         $prompt = $self->prompt();
     }
 
-    $self->quit();
+    $self->quit;
 }
 
 # ----------------------------------------------------------------------
@@ -1815,7 +1847,7 @@ darren chamberlain E<lt>darren@cpan.orgE<gt>
 
 =head1 REVISION
 
-This documentation describes C<Shell::Base>, $Revision$.
+This documentation describes C<Shell::Base>, $Revision: 1.21.4.1 $.
 
 =head1 COPYRIGHT
 
